pub struct Scope { /* private fields */ }Expand description
One immutable lexical scope with its two-namespace symbol tables.
Implementations
Sourceimpl Scope
impl Scope
pub const fn kind(&self) -> ScopeKind
pub const fn parent(&self) -> Option<ScopeId>
Sourcepub fn value(&self, name: &str) -> Option<SymbolId>
pub fn value(&self, name: &str) -> Option<SymbolId>
Returns the value binding declared directly in this scope, if any.
Sourcepub fn type_binding(&self, name: &str) -> Option<SymbolId>
pub fn type_binding(&self, name: &str) -> Option<SymbolId>
Returns the type binding declared directly in this scope, if any.