pub struct RuleDefinition { /* private fields */ }Expand description
The complete metadata required to register a lint rule.
Fields and construction are private: a rule identity can only come from RULES,
so a code or slug cannot exist without the rest of its metadata.
Implementations
Sourceimpl RuleDefinition
impl RuleDefinition
pub const fn id(&self) -> RuleId
pub const fn code(&self) -> &'static str
pub const fn slug(&self) -> &'static str
pub const fn group(&self) -> RuleGroup
pub const fn default_level(&self) -> LintLevel
pub const fn rationale(&self) -> &'static str
pub const fn sound_alternative(&self) -> &'static str
pub const fn silence_flag(&self) -> &'static str
pub const fn examples(&self) -> RuleExamples