TypeNode

Enum TypeNode 

pub enum TypeNode {
Show 22 variants Keyword(KeywordType), Literal(TypeLiteral), Reference(TypeReference), Union(Vec<Ty>), Intersection(Vec<Ty>), Array(Box<Ty>), Tuple(TupleType), Object(ObjectType), Function(FunctionType), Constructor(ConstructorType), Query(TypeQuery), Operator { operator: TypeOperator, operand: Box<Ty>, }, IndexedAccess(IndexedAccessType), Conditional(ConditionalType), Mapped(MappedType), Infer(InferType), Import(ImportType), TemplateLiteral(TemplateLiteralType), Parenthesized(Box<Ty>), This, Predicate(TypePredicate), Missing(MissingNode),
}
Type syntax is kept in this closed enum so erasure never has to inspect a runtime expression variant.

Variants



Keyword(KeywordType)



Literal(TypeLiteral)



Reference(TypeReference)



Union(Vec<Ty>)



Intersection(Vec<Ty>)



Array(Box<Ty>)



Tuple(TupleType)



Object(ObjectType)



Function(FunctionType)



Constructor(ConstructorType)



Query(TypeQuery)



Operator

Fields

operator: TypeOperator
operand: Box<Ty>


IndexedAccess(IndexedAccessType)



Conditional(ConditionalType)



Mapped(MappedType)



Infer(InferType)



Import(ImportType)



TemplateLiteral(TemplateLiteralType)



Parenthesized(Box<Ty>)



This



Predicate(TypePredicate)



Missing(MissingNode)