pub struct SemanticModel { /* private fields */ }Expand description
The immutable product of semantic analysis.
Implementations
Sourceimpl SemanticModel
impl SemanticModel
Sourcepub const fn module_scope(&self) -> ScopeId
pub const fn module_scope(&self) -> ScopeId
Returns the top-level module scope.
Sourcepub fn symbol_type(&self, id: SymbolId) -> TypeId
pub fn symbol_type(&self, id: SymbolId) -> TypeId
Returns the declared or inferred type of a bound name.
Sourcepub const fn facts(&self) -> &AnalysisFacts
pub const fn facts(&self) -> &AnalysisFacts
Returns the immutable semantic evidence consumed by lint rules.
Sourcepub fn reference(&self, node: NodeId) -> Option<SymbolId>
pub fn reference(&self, node: NodeId) -> Option<SymbolId>
Returns the symbol an identifier reference resolved to, if any.
Sourcepub fn resolved_reference_count(&self) -> usize
pub fn resolved_reference_count(&self) -> usize
Returns how many identifier references resolved to a local binding.