pub struct CompilerOptions { /* private fields */ }Expand description
The compiler options needed by deterministic project and module resolution.
Unknown compiler options remain available through ProjectConfig::raw so this
foundation does not silently reinterpret options owned by later compiler phases.
Implementations
Sourceimpl CompilerOptions
impl CompilerOptions
pub fn target(&self) -> Option<&str>
pub fn module(&self) -> Option<&str>
pub fn module_resolution(&self) -> Option<&str>
pub fn jsx(&self) -> Option<&str>
pub const fn strict(&self) -> bool
pub const fn allow_js(&self) -> bool
pub const fn check_js(&self) -> bool
pub const fn resolve_json_module(&self) -> bool
pub fn base_url(&self) -> &Path
pub fn root_dir(&self) -> Option<&Path>
pub fn out_dir(&self) -> Option<&Path>
pub fn paths(&self) -> &[PathMapping]